atomic module
=============

This modules contains basic atomic parameters (i.e. atomic numbers, element symbols)

.. automodule:: pyatomdb.atomic
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
